@@ -1,3 +1,4 @@
+#!/bin/sh
 # This little script creates a build/ directory, enters it
 # and builds BibleTime there.
 #
@@ -5,11 +6,6 @@
 # just from there: ./build/install/bin/bibletime. It will find all
 # required files.
 
-if [ "$(uname)" == "Darwin" ]; then
-    # OSX/homebrew
-    export CMAKE_PREFIX_PATH=/usr/local/opt/qt5/lib/cmake/
-fi
-
 if [ ! -d build ]; then mkdir build; fi
 cd build
 cmake -D CMAKE_BUILD_TYPE=Debug -D CMAKE_INSTALL_PREFIX="install/" ..  || exit 1
