@@ -2,10 +2,11 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
@@ -207,6 +208,12 @@ wrong, or if the config file was write protected return false.
     */
     bool isEncrypted() const;
 
+    /**
+    *  Gets the "UnlockInfo" tag value from the module's config file
+    *  @return Unlock information string (may be empty if not specified for module)
+    **/
+    QString getUnlockInfo();
+
     /**
     * This function returns true if this module is locked (encrypted + correct cipher key),
     * otherwise return false.
@@ -420,6 +427,9 @@ protected: /* Methods: */
     QString getSimpleConfigEntry(const QString & name) const;
     QString getFormattedConfigEntry(const QString & name) const;
 
+    bool hasImportantFilterOption() const;
+    void setImportantFilterOptions(bool enable);
+
 signals:
 
     void hasIndexChanged(bool hasIndex);
