@@ -2,10 +2,11 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
@@ -32,6 +33,8 @@ class TeiToHtml: public sword::TEIHTMLHREF {
     private: /* Methods: */
         void renderReference(const char *osisRef, sword::SWBuf &buf,
                              sword::BasicFilterUserData *myUserData);
+        void renderTargetReference(const char *osisRef, sword::SWBuf &buf,
+                             sword::BasicFilterUserData *myUserData);
 };
 
 } // namespace Filters
