@@ -2,10 +2,11 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
@@ -61,7 +62,7 @@ class CDisplayTemplateMgr {
 
         /**
           \param[out] errorMessage Set to error string on error, otherwise set
-                                   to QString::null.
+                                   to QString().
         */
         explicit CDisplayTemplateMgr(QString & errorMessage);
 
@@ -105,6 +106,12 @@ class CDisplayTemplateMgr {
             BT_ASSERT(m_instance);
             return m_instance;
         }
+        /**
+          \brief Turn on or off displaying module names during parallel text rendering
+
+          \param visible display module names
+        */
+        void setMultiModuleHeadersVisible(bool visible);
 
     private: /* Methods: */
 
@@ -114,6 +121,7 @@ class CDisplayTemplateMgr {
 
     private: /* Fields: */
 
+        bool m_multiModuleHeaders;
         QHash<QString, QString> m_templateMap;
         QHash<QString, QString> m_cssMap;
         static CDisplayTemplateMgr * m_instance;
