@@ -2,10 +2,11 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
@@ -74,9 +75,9 @@ struct ParseOptions {
 
 /* Methods: */
 
-    inline ParseOptions(QString const & refDestinationModule_ = QString::null,
-                        QString const & refBase_ = QString::null,
-                        QString const & sourceLanguage_ = QString::null,
+    inline ParseOptions(QString const & refDestinationModule_ = QString(),
+                        QString const & refBase_ = QString(),
+                        QString const & sourceLanguage_ = QString(),
                         QString const & destinationLanguage_ = "en")
         : refDestinationModule(refDestinationModule_)
         , refBase(refBase_)
