@@ -9,7 +9,7 @@
 * version 2.0.
 *
 **********/
-
+#include <QTextEdit>
 #include "btmoduletextmodel.h"
 
 #include "../../util/btassert.h"
@@ -32,30 +32,35 @@ BtModuleTextModel::BtModuleTextModel(QObject *parent)
     : QAbstractListModel(parent),
       m_firstEntry(0),
       m_maxEntries(0),
-      m_firstSelected(-1),
-      m_lastSelected(-1),
-      m_posFirst(-1),
-      m_posLast(-1),
       m_textFilter(nullptr) {
 
     m_findState.enabled = false;
     QHash<int, QByteArray> roleNames;
     roleNames[ModuleEntry::ReferenceRole] =  "keyName";             // reference
     roleNames[ModuleEntry::TextRole] = "line";                      // not used
+
+    roleNames[ModuleEntry::Text0Role] = "text0";                    // text in column 0
     roleNames[ModuleEntry::Text1Role] = "text1";                    // text in column 1
     roleNames[ModuleEntry::Text2Role] = "text2";                    // text in column 2
     roleNames[ModuleEntry::Text3Role] = "text3";                    // text in column 3
     roleNames[ModuleEntry::Text4Role] = "text4";                    // text in column 4
+    roleNames[ModuleEntry::Text5Role] = "text5";                    // text in column 5
+    roleNames[ModuleEntry::Text6Role] = "text6";                    // text in column 6
+    roleNames[ModuleEntry::Text7Role] = "text7";                    // text in column 7
+    roleNames[ModuleEntry::Text8Role] = "text8";                    // text in column 8
+    roleNames[ModuleEntry::Text9Role] = "text9";                    // text in column 9
+
+    roleNames[ModuleEntry::Title0Role] = "title0";                  // title in column 0
     roleNames[ModuleEntry::Title1Role] = "title1";                  // title in column 1
     roleNames[ModuleEntry::Title2Role] = "title2";                  // title in column 2
     roleNames[ModuleEntry::Title3Role] = "title3";                  // title in column 3
     roleNames[ModuleEntry::Title4Role] = "title4";                  // title in column 4
-    roleNames[ModuleEntry::Selected] = "selected";                  // bool - This index row is partially or fully selected
-    roleNames[ModuleEntry::ColumnSelected] = "columnSelected";      // which column contains the selected text
-    roleNames[ModuleEntry::PosFirst] = "posFirst";                  // on the first item selected, selection starts here
-    roleNames[ModuleEntry::PosLast] = "posLast";                    // on the last item selected, selection ends here
-    roleNames[ModuleEntry::SelectFirstIndex] = "selectFirstIndex";  // bool - item is first selected item
-    roleNames[ModuleEntry::SelectLastIndex] = "selectLastIndex";    // bool - item is last selected item
+    roleNames[ModuleEntry::Title5Role] = "title5";                  // title in column 5
+    roleNames[ModuleEntry::Title6Role] = "title6";                  // title in column 6
+    roleNames[ModuleEntry::Title7Role] = "title7";                  // title in column 7
+    roleNames[ModuleEntry::Title8Role] = "title8";                  // title in column 8
+    roleNames[ModuleEntry::Title9Role] = "title9";                  // title in column 9
+
     setRoleNames(roleNames);
     m_displayOptions.verseNumbers = 1;
     m_displayOptions.lineBreaks = 1;
@@ -113,90 +118,9 @@ void BtModuleTextModel::setModules(const QStringList& modules) {
     reloadModules();
 }
 
-bool BtModuleTextModel::isSelected(int index) const {
-    if (index <= m_lastSelected && index >= m_firstSelected)
-        return true;
-    return false;
-}
-
-void BtModuleTextModel::deSelect() {
-    if (m_firstSelected < 0)
-        return;
-    int first = m_firstSelected;
-    int last = m_lastSelected;
-    m_firstSelected = -1;
-    m_lastSelected = -1;
-    m_columnSelected = -1;
-    dataChanged(index(first,0), index(last,0));
-}
-
-bool BtModuleTextModel::isSelected() {
-    if (m_firstSelected < 0)
-        return false;
-    return true;
-}
-
-void BtModuleTextModel::selectByIndex(int first, int last, int column, int posFirst, int posLast) {
-    if (m_firstSelected == first &&
-            m_lastSelected == last &&
-            m_columnSelected == column &&
-            m_posFirst == posFirst &&
-            m_posLast == posLast)
-        return;
-
-    deSelect();
-    m_firstSelected = first;
-    m_lastSelected = last;
-    m_columnSelected = column;
-    m_posFirst = posFirst;
-    m_posLast = posLast;
-    dataChanged(index(m_firstSelected,0), index(m_lastSelected,0));
-}
-
-static bool getColumnSelected(int role, int column) {
-    if (role == ModuleEntry::Text1Role && column == 0)
-        return true;
-    if (role == ModuleEntry::Text2Role && column == 1)
-        return true;
-    if (role == ModuleEntry::Text3Role && column == 2)
-        return true;
-    if (role == ModuleEntry::Text4Role && column == 3)
-        return true;
-    return false;
-}
-
-bool BtModuleTextModel::hasSelectedText() {
-    return m_firstSelected >= 0;
-}
 
 QVariant BtModuleTextModel::data(const QModelIndex & index, int role) const {
 
-    bool selected = isSelected(index.row());
-    if (role == ModuleEntry::Selected) {
-        return selected;
-    }
-    if (role == ModuleEntry::ColumnSelected) {
-        return m_columnSelected;
-    }
-    if (role == ModuleEntry::PosFirst) {
-        if (index.row() == m_firstSelected)
-            return m_posFirst;
-        return -1;
-    }
-    if (role == ModuleEntry::PosLast) {
-        if (index.row() == m_lastSelected)
-            return m_posLast;
-        return -1;
-    }
-
-    if (role == ModuleEntry::SelectFirstIndex) {
-        return index.row() == m_firstSelected;
-    }
-
-    if (role == ModuleEntry::SelectLastIndex) {
-        return index.row() == m_lastSelected;
-    }
-
     QString text;
     if (isBible() || isCommentary())
         text = verseData(index, role);
@@ -208,8 +132,7 @@ QVariant BtModuleTextModel::data(const QModelIndex & index, int role) const {
         text = "invalid";
 
     if (m_textFilter) {
-        bool selected = isSelected(index.row()) && getColumnSelected(role, m_columnSelected);
-        text = m_textFilter->processText(text,selected);
+        text = m_textFilter->processText(text);
     }
 
     if ( ! m_highlightWords.isEmpty()) {
@@ -231,7 +154,7 @@ QString BtModuleTextModel::lexiconData(const QModelIndex & index, int role) cons
     QString keyName = lexiconModule->entries()[row];
 
     if (role == ModuleEntry::TextRole ||
-            role == ModuleEntry::Text1Role) {
+            role == ModuleEntry::Text0Role) {
         Rendering::CEntryDisplay entryDisplay;
         QString text = entryDisplay.text(moduleList, keyName,
                                          m_displayOptions, m_filterOptions);
@@ -247,7 +170,7 @@ QString BtModuleTextModel::lexiconData(const QModelIndex & index, int role) cons
 
 QString BtModuleTextModel::bookData(const QModelIndex & index, int role) const {
     if (role == ModuleEntry::TextRole ||
-            role == ModuleEntry::Text1Role) {
+            role == ModuleEntry::Text0Role) {
         const CSwordBookModuleInfo *bookModule = qobject_cast<const CSwordBookModuleInfo*>(m_moduleInfoList.at(0));
         CSwordTreeKey key(bookModule->tree(), bookModule);
         int bookIndex = index.row() * 4;
@@ -267,27 +190,19 @@ QString BtModuleTextModel::bookData(const QModelIndex & index, int role) const {
 }
 
 static int getColumnFromRole(int role) {
-    if (role >= ModuleEntry::Text1Role && role <= ModuleEntry::Text4Role)
-        return role - ModuleEntry::Text1Role;
-    if (role >= ModuleEntry::Title1Role && role <= ModuleEntry::Title4Role)
-        return role - ModuleEntry::Title1Role;
+    if (role >= ModuleEntry::Text0Role && role <= ModuleEntry::Text9Role)
+        return role - ModuleEntry::Text0Role;
+    if (role >= ModuleEntry::Title0Role && role <= ModuleEntry::Title9Role)
+        return role - ModuleEntry::Title0Role;
     return 0;
 }
 
-
 QString BtModuleTextModel::verseData(const QModelIndex & index, int role) const {
     int row = index.row();
     CSwordVerseKey key = indexToVerseKey(row);
     int verse = key.getVerse();
-    if (role == ModuleEntry::TextRole ||
-            role == ModuleEntry::Text1Role ||
-            role == ModuleEntry::Text2Role ||
-            role == ModuleEntry::Text3Role ||
-            role == ModuleEntry::Text4Role ||
-            role == ModuleEntry::Title1Role ||
-            role == ModuleEntry::Title2Role ||
-            role == ModuleEntry::Title3Role ||
-            role == ModuleEntry::Title4Role) {
+
+    if (role >= ModuleEntry::TextRole && role <= ModuleEntry::Title9Role) {
         if (verse == 0)
             return QString();
         QString text;
@@ -303,7 +218,7 @@ QString BtModuleTextModel::verseData(const QModelIndex & index, int role) const
             int column = getColumnFromRole(role);
             CSwordModuleInfo const * module;
             if ((column + 1) > m_moduleInfoList.count())
-                module = m_moduleInfoList.at(0);
+                return "";
             else
                 module = m_moduleInfoList.at(column);
             modules.append(module);
@@ -311,10 +226,7 @@ QString BtModuleTextModel::verseData(const QModelIndex & index, int role) const
             mKey.setKey(key.key());
 
             // Title only for verse 1 of Personal commentary
-            if (role == ModuleEntry::Title1Role ||
-                    role == ModuleEntry::Title2Role ||
-                    role == ModuleEntry::Title3Role ||
-                    role == ModuleEntry::Title4Role ){
+            if (role >= ModuleEntry::Title0Role && role <= ModuleEntry::Title9Role) {
                 if (module->isWritable() && verse == 1)
                     return "<center><h3>" + chapterTitle + "</h3></center>";
                 return "";
@@ -436,6 +348,16 @@ CSwordVerseKey BtModuleTextModel::indexToVerseKey(int index) const
     return key;
 }
 
+int BtModuleTextModel::indexToVerse(int index) const
+{
+    const CSwordModuleInfo* module = m_moduleInfoList.at(0);
+    CSwordVerseKey key(module);
+
+    key.setIntros(true);
+    key.setIndex(index + m_firstEntry);
+    return key.getVerse();
+}
+
 CSwordKey* BtModuleTextModel::indexToKey(int index, int moduleNum) const
 {
     const CSwordModuleInfo* module = m_moduleInfoList.at(moduleNum);
@@ -474,6 +396,10 @@ QString BtModuleTextModel::indexToKeyName(int index) const {
     return keyName;
 }
 
+int BtModuleTextModel::getFirstEntryIndex() const {
+    return m_firstEntry;
+}
+
 void BtModuleTextModel::setFindState(const FindState& findState) {
     if (m_findState.enabled && m_findState.index != findState.index) {
         QModelIndex oldIndexToClear = index(m_findState.index, 0);
@@ -515,23 +441,12 @@ void BtModuleTextModel::setTextFilter(BtModuleTextFilter * textFilter) {
     m_textFilter = textFilter;
 }
 
-static int convertRoleToColumn(int role) {
-    int column = 0;
-    if (role == ModuleEntry::Text2Role)
-        column = 1;
-    if (role == ModuleEntry::Text3Role)
-        column = 2;
-    if (role == ModuleEntry::Text4Role)
-        column = 3;
-    return column;
-}
-
 bool BtModuleTextModel::setData(
         const QModelIndex &index,
         const QVariant &value,
         int role) {
     CSwordVerseKey key = indexToVerseKey(index.row());
-    int column = convertRoleToColumn(role);
+    int column = getColumnFromRole(role);
     const CSwordModuleInfo* module = m_moduleInfoList.at(column);
     CSwordVerseKey mKey(module);
     mKey.setKey(key);
