@@ -40,20 +40,28 @@ struct ModuleEntry {
     enum TextRoles {
         ReferenceRole = Qt::UserRole + 1,
         TextRole = Qt::UserRole + 2,
-        Text1Role = Qt::UserRole + 3,
-        Text2Role = Qt::UserRole + 4,
-        Text3Role = Qt::UserRole + 5,
-        Text4Role = Qt::UserRole + 6,
-        Title1Role = Qt::UserRole + 7,
-        Title2Role = Qt::UserRole + 8,
-        Title3Role = Qt::UserRole + 9,
-        Title4Role = Qt::UserRole + 10,
-        Selected = Qt::UserRole + 11,
-        ColumnSelected = Qt::UserRole + 12,
-        PosFirst = Qt::UserRole + 13,
-        PosLast = Qt::UserRole + 14,
-        SelectFirstIndex = Qt::UserRole + 15,
-        SelectLastIndex = Qt::UserRole + 16
+
+        Text0Role = Qt::UserRole + 10,
+        Text1Role = Qt::UserRole + 11,
+        Text2Role = Qt::UserRole + 12,
+        Text3Role = Qt::UserRole + 13,
+        Text4Role = Qt::UserRole + 14,
+        Text5Role = Qt::UserRole + 15,
+        Text6Role = Qt::UserRole + 16,
+        Text7Role = Qt::UserRole + 17,
+        Text8Role = Qt::UserRole + 18,
+        Text9Role = Qt::UserRole + 19,
+
+        Title0Role = Qt::UserRole + 20,
+        Title1Role = Qt::UserRole + 21,
+        Title2Role = Qt::UserRole + 22,
+        Title3Role = Qt::UserRole + 23,
+        Title4Role = Qt::UserRole + 24,
+        Title5Role = Qt::UserRole + 25,
+        Title6Role = Qt::UserRole + 26,
+        Title7Role = Qt::UserRole + 27,
+        Title8Role = Qt::UserRole + 28,
+        Title9Role = Qt::UserRole + 29
     };
 };
 
@@ -61,7 +69,7 @@ class BtModuleTextFilter {
 
 public:
     virtual ~BtModuleTextFilter() = 0;
-    virtual QString processText(const QString& text, bool selected=false) = 0;
+    virtual QString processText(const QString& text) = 0;
 };
 
 
@@ -103,10 +111,13 @@ public:
     /** Convert index(row) into CSwordVerseKey. */
     CSwordVerseKey indexToVerseKey(int index) const;
 
+    /** Convert index(row) into verse. */
+    int indexToVerse(int index) const;
+
     /** Convert index(row) into CSwordVerseKey. */
     CSwordKey* indexToKey(int index, int moduleNum) const;
 
-    /** Convert CSwordKey into index(row). */
+    /** Convert CSwordKey into index. */
     int keyToIndex(const CSwordKey* key) const;
 
     /** Convert CSwordVerseKey into index(row). */
@@ -115,6 +126,9 @@ public:
     /** Get reference name from index(row). */
     QString indexToKeyName(int index) const;
 
+    /** Get index offset of first entry of module */
+    int getFirstEntryIndex() const;
+
     /** Reimplemented from QAbstractItemModel. */
     int columnCount(const QModelIndex & parent = QModelIndex()) const override;
 
@@ -129,25 +143,8 @@ public:
     virtual bool setData(const QModelIndex &index,
                          const QVariant &value, int role = Qt::EditRole) override;
 
-    void deSelect();
-    bool isSelected();
-    void selectByIndex(int first, int last, int column, int posFirst, int posLast);
-    int getFirstSelectionIndex() {
-        return m_firstSelected;
-    }
-    int getLastSelectionIndex() {
-        return m_lastSelected;
-    }
-
-    int getSelectionColumn() {
-        return m_columnSelected;
-    }
-
-    bool hasSelectedText();
-
     void setDisplayOptions(const DisplayOptions & displayOptions);
 
-
     /** Set the state of the currently found word functionality */
     void setFindState(const FindState& findState);
 
@@ -196,16 +193,10 @@ private:
 
     int m_firstEntry;
     int m_maxEntries;
-    int m_firstSelected;
-    int m_lastSelected;
-    int m_columnSelected;
-    int m_posFirst;
-    int m_posLast;
     BtModuleTextFilter * m_textFilter;
     DisplayOptions m_displayOptions;
     FilterOptions m_filterOptions;
     FindState m_findState;
 };
 
-
 #endif
