@@ -1,9 +1,12 @@
 /*********
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
+*
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
@@ -16,10 +19,10 @@
 #include <QTextEdit>
 #include <QVBoxLayout>
 #include <QWidget>
-#include "bibletimeapp.h"
-#include "frontend/messagedialog.h"
-#include "util/btconnect.h"
-#include "util/cresmgr.h"
+#include "../../util/btconnect.h"
+#include "../../util/cresmgr.h"
+#include "../bibletimeapp.h"
+#include "../messagedialog.h"
 
 
 BtEditBookmarkDialog::BtEditBookmarkDialog(const QString &key,
