@@ -1,9 +1,12 @@
 /*********
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
+*
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
@@ -22,28 +25,37 @@
 #include <QPaintEvent>
 #include <QTimer>
 #include <QToolTip>
-#include "backend/config/btconfig.h"
-#include "backend/drivers/cswordmoduleinfo.h"
-#include "backend/btbookmarksmodel.h"
-#include "backend/managers/referencemanager.h"
-#include "bibletime.h"
-#include "bibletimeapp.h"
-#include "frontend/btprinter.h"
-#include "frontend/cdragdrop.h"
-#include "frontend/cinfodisplay.h"
-#include "frontend/messagedialog.h"
-#include "frontend/searchdialog/csearchdialog.h"
-#include "frontend/bookmarks/bteditbookmarkdialog.h"
-#include "frontend/bookmarks/cbookmarkindex.h"
-#include "util/btassert.h"
-#include "util/btconnect.h"
-#include "util/bticons.h"
-#include "util/btscopeexit.h"
-#include "util/cresmgr.h"
-#include "util/tool.h"
-#include "util/directory.h"
+#include "../../backend/config/btconfig.h"
+#include "../../backend/drivers/cswordmoduleinfo.h"
+#include "../../backend/btbookmarksmodel.h"
+#include "../../backend/managers/referencemanager.h"
+#include "../../util/btassert.h"
+#include "../../util/btconnect.h"
+#include "../../util/bticons.h"
+#include "../../util/btscopeexit.h"
+#include "../../util/cresmgr.h"
+#include "../../util/tool.h"
+#include "../../util/directory.h"
+#include "../bibletime.h"
+#include "../bibletimeapp.h"
+#include "../bookmarks/bteditbookmarkdialog.h"
+#include "../bookmarks/cbookmarkindex.h"
+#include "../btprinter.h"
+#include "../BtMimeData.h"
+#include "../cinfodisplay.h"
+#include "../messagedialog.h"
+#include "../searchdialog/csearchdialog.h"
 
 
+namespace {
+
+QString fileDialogFilter() {
+    return QObject::tr("BibleTime bookmark files") + " (*.btb);;"
+           + QObject::tr("All files") + " (*)";
+}
+
+} // anonymous namespace
+
 CBookmarkIndex::CBookmarkIndex(QWidget * const parent)
         : QTreeView{parent}
         , m_magTimer{this}
@@ -197,7 +209,7 @@ QMimeData * CBookmarkIndex::dragObject() {
                if these were uninstalled: */
             CSwordModuleInfo * const module =
                     m_bookmarksModel->module(widgetItem);
-            const QString moduleName = module ? module->name() : QString::null;
+            const QString moduleName = module ? module->name() : QString();
             mimeData->appendBookmark(moduleName, m_bookmarksModel->key(widgetItem),
                                      m_bookmarksModel->description(widgetItem));
         }
@@ -442,7 +454,7 @@ bool CBookmarkIndex::hasBookmarksRecursively(QModelIndexList items) const {
         if (m_bookmarksModel->isFolder(index)) {
             int const numChildren = m_bookmarksModel->rowCount(index);
             for (int i = 0; i < numChildren; i++)
-                items.append(index.child(i, 0));
+                items.append(index.model()->index(i, 0, index));
         }
     }
     return false;
@@ -551,8 +563,7 @@ void CBookmarkIndex::exportBookmarks() {
                 nullptr,
                 QObject::tr("Export Bookmarks"),
                 "",
-                QObject::tr("BibleTime bookmark files") + QString(" (*.btb);;")
-                + QObject::tr("All files") + QString(" (*.*)"));
+                fileDialogFilter());
     if (!fileName.isEmpty())
         m_bookmarksModel->save(fileName, currentIndex());
 }
@@ -565,9 +576,7 @@ void CBookmarkIndex::importBookmarks() {
                     nullptr,
                     QObject::tr("Import bookmarks"),
                     "",
-                    QObject::tr("BibleTime bookmark files")
-                    + QString(" (*.btb);;")
-                    + QObject::tr("All files") + QString(" (*.*)"));
+                    fileDialogFilter());
     if (!fileName.isEmpty())
         m_bookmarksModel->load(fileName, currentIndex());
 }
@@ -592,7 +601,7 @@ void CBookmarkIndex::printBookmarks() {
             } else if (m_bookmarksModel->isFolder(index)) {
                 int const numChildren = m_bookmarksModel->rowCount(index);
                 for (int i = 0; i < numChildren; i++)
-                    items.append(index.child(i, 0));
+                    items.append(index.model()->index(i, 0, index));
             }
         }
     }
