@@ -192,11 +192,11 @@ void BtAboutDialog::retranslateContributorsTab() {
     ****************************************************************************************/
     content += tr("The following people translated BibleTime into their language:");
     content += "</b></p><ul>"
-                   "<li>Horatiu Alexe</li>"
                    "<li>Roy Alvear Aguirre</li>"
+                   "<li>Horatiu Alexe</li>"
                    "<li>Andrew Alfy</li>"
-                   "<li>Luis Barron</li>"
                    "<li>Jan B&#x11B;lohoubek</li>"
+                   "<li>Luis Barron</li>"
                    "<li>M&aacute;rio Castanheira</li>"
                    "<li>Chun-shek Chan</li>"
                    "<li>Ján Ďanovský</li>"
@@ -205,7 +205,9 @@ void BtAboutDialog::retranslateContributorsTab() {
                    "<li>Eeli Kaikkonen</li>"
                    "<li>Ilpo Kantonen</li>"
                    "<li>Pavel Laukko</li>"
+                   "<li>Johan van der Lingen</li>"
                    "<li>Piotr Markiewicz</li>"
+                   "<li>Konstantin Maslyuk</li>"
                    "<li>G&eacute;za Nov&aacute;k</li>"
                    "<li>Gabriel P&eacute;rez</li>"
                    "<li>Igor Plisco</li>"
@@ -213,15 +215,15 @@ void BtAboutDialog::retranslateContributorsTab() {
                    "<li>Jaak Ristioja</li>"
                    "<li>Igor Rykhlin</li>"
                    "<li>Vlad Savitsky</li>"
-                   "<li>Henrik Sonesson</li>"
-                   "<li>Johan van der Lingen</li>"
-                   "<li>Damian Wrzalski</li>"
-                   "<li>Konstantin Maslyuk</li>"
                    "<li>Jean Van Schaftingen</li>"
-                   "<li>Roland Teschner</li>"
+                   "<li>Flavio Theodor de Lima Silva</li>"
+                   "<li>Henrik Sonesson</li>"
                    "<li>Giovanni Tedaldi</li>"
+                   "<li>Roland Teschner</li>"
+                   "<li>Damian Wrzalski</li>"
                    "<li>Dmitry Yurevich</li>"
                    "<li>Esteban Zeller</li>"
+                   "<li>Aaron Zhou</li>"
                "</ul><p>";
     content += tr("Some names may be missing, please file an issue at %1 if "
                   "you notice errors or omissions.").arg(MAKE_LINK_STATIC(
