@@ -2,10 +2,11 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
 *
-* Copyright 1999-2014 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
@@ -15,21 +16,21 @@
 #include <QDialog>
 
 class QDialogButtonBox;
+class QLabel;
 class QTabWidget;
 class QUrl;
-class QWebView;
-class QLabel;
+class QTextBrowser;
 
 class BtAboutDialog: public QDialog {
         Q_OBJECT
     public:
-        BtAboutDialog(QWidget *parent = 0, Qt::WindowFlags wflags = Qt::Dialog);
+        BtAboutDialog(QWidget *parent = nullptr, Qt::WindowFlags wflags = Qt::Dialog);
 
     protected:
-        virtual void resizeEvent(QResizeEvent* event);
+        void resizeEvent(QResizeEvent* event) override;
 
     private:
-        void initTab(QWebView *&tab);
+        void initTab(QTextBrowser *&tab);
 
         void retranslateUi();
         void retranslateBtTab();
@@ -43,11 +44,11 @@ class BtAboutDialog: public QDialog {
 
     private:
         QTabWidget *m_tabWidget;
-        QWebView *m_bibletimeTab;
-        QWebView *m_contributorsTab;
-        QWebView *m_swordTab;
-        QWebView *m_qtTab;
-        QWebView *m_licenceTab;
+        QTextBrowser *m_bibletimeTab;
+        QTextBrowser *m_contributorsTab;
+        QTextBrowser *m_swordTab;
+        QTextBrowser *m_qtTab;
+        QTextBrowser *m_licenceTab;
         QDialogButtonBox *m_buttonBox;
         QLabel *m_iconLabel;
         QLabel *m_versionLabel;
