@@ -2,21 +2,21 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
 *
-* Copyright 1999-2016 by the BibleTime developers.
+* Copyright 1999-2020 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#include "frontend/btbookshelfgroupingmenu.h"
+#include "btbookshelfgroupingmenu.h"
 
+#include "../util/btassert.h"
+#include "../util/btconnect.h"
+#include "../util/cresmgr.h"
+#include "../util/directory.h"
 #include "bibletimeapp.h"
-#include "util/btassert.h"
-#include "util/btconnect.h"
-#include "util/cresmgr.h"
-#include "util/directory.h"
 
 
 namespace {
