@@ -2,26 +2,26 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
 *
-* Copyright 1999-2016 by the BibleTime developers.
+* Copyright 1999-2020 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#include "frontend/btmodulechooserdialog.h"
+#include "btmodulechooserdialog.h"
 
 #include <QDialogButtonBox>
 #include <QLabel>
 #include <QVBoxLayout>
-#include "backend/bookshelfmodel/btbookshelftreemodel.h"
-#include "frontend/btaboutmoduledialog.h"
-#include "frontend/btbookshelfview.h"
-#include "frontend/btbookshelfwidget.h"
-#include "frontend/messagedialog.h"
-#include "util/btconnect.h"
-#include "util/tool.h"
+#include "../backend/bookshelfmodel/btbookshelftreemodel.h"
+#include "../util/btconnect.h"
+#include "../util/tool.h"
+#include "btaboutmoduledialog.h"
+#include "btbookshelfview.h"
+#include "btbookshelfwidget.h"
+#include "messagedialog.h"
 
 
 BtModuleChooserDialog::BtModuleChooserDialog(QWidget *parent, Qt::WindowFlags flags)
