@@ -2,22 +2,22 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
 *
-* Copyright 1999-2016 by the BibleTime developers.
+* Copyright 1999-2020 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#include "frontend/btopenworkaction.h"
+#include "btopenworkaction.h"
 
-#include "backend/bookshelfmodel/btbookshelffiltermodel.h"
-#include "backend/managers/cswordbackend.h"
+#include "../backend/bookshelfmodel/btbookshelffiltermodel.h"
+#include "../backend/managers/cswordbackend.h"
+#include "../util/btconnect.h"
+#include "../util/cresmgr.h"
 #include "bibletimeapp.h"
-#include "frontend/btbookshelfgroupingmenu.h"
-#include "util/btconnect.h"
-#include "util/cresmgr.h"
+#include "btbookshelfgroupingmenu.h"
 
 
 BtOpenWorkActionMenu::BtOpenWorkActionMenu(const QString &groupingConfigKey,
@@ -50,7 +50,8 @@ void BtOpenWorkActionMenu::retranslateUi() {
                                     "this menu."));
 }
 
-void BtOpenWorkActionMenu::postBuildMenu() {
+void BtOpenWorkActionMenu::postBuildMenu(QActionGroup * actions) {
+    Q_UNUSED(actions);
     addSeparator();
     m_groupingMenu = new BtBookshelfGroupingMenu(false, this);
 
