@@ -2,10 +2,11 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
@@ -13,9 +14,9 @@
 #define BTPRINTER_H
 
 #include <QObject>
-#include "backend/rendering/cdisplayrendering.h"
+#include "../backend/rendering/cdisplayrendering.h"
 
-#include "backend/managers/cswordbackend.h"
+#include "../backend/managers/cswordbackend.h"
 
 
 /** \brief Manages the print item queue and printing. */
