@@ -1,13 +1,16 @@
 /*********
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
+*
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
-#include "frontend/cexportmanager.h"
+#include "cexportmanager.h"
 
 #include <QApplication>
 #include <QClipboard>
@@ -15,17 +18,17 @@
 #include <QList>
 #include <QProgressDialog>
 #include <QTextStream>
-#include "backend/drivers/cswordmoduleinfo.h"
-#include "backend/keys/cswordkey.h"
-#include "backend/keys/cswordversekey.h"
-#include "backend/managers/referencemanager.h"
-#include "backend/managers/cdisplaytemplatemgr.h"
-#include "backend/rendering/centrydisplay.h"
-#include "backend/rendering/chtmlexportrendering.h"
-#include "backend/rendering/cplaintextexportrendering.h"
-#include "frontend/btprinter.h"
-#include "util/btassert.h"
-#include "util/tool.h"
+#include "../backend/drivers/cswordmoduleinfo.h"
+#include "../backend/keys/cswordkey.h"
+#include "../backend/keys/cswordversekey.h"
+#include "../backend/managers/referencemanager.h"
+#include "../backend/managers/cdisplaytemplatemgr.h"
+#include "../backend/rendering/centrydisplay.h"
+#include "../backend/rendering/chtmlexportrendering.h"
+#include "../backend/rendering/cplaintextexportrendering.h"
+#include "../util/btassert.h"
+#include "../util/tool.h"
+#include "btprinter.h"
 
 // Sword includes:
 #include <swkey.h>
@@ -70,7 +73,8 @@ CExportManager::~CExportManager() {
 
 bool CExportManager::saveKey(CSwordKey const * const key,
                              Format const format,
-                             bool const addText)
+                             bool const addText,
+                             const BtConstModuleList& modules)
 {
     if (!key || !key->module())
         return false;
@@ -80,8 +84,6 @@ bool CExportManager::saveKey(CSwordKey const * const key,
 
     QString text;
     {
-        BtConstModuleList modules;
-        modules.append(key->module());
         CSwordVerseKey const * const vk =
                 dynamic_cast<CSwordVerseKey const *>(key);
         auto const render = newRenderer(format, addText);
@@ -90,11 +92,13 @@ bool CExportManager::saveKey(CSwordKey const * const key,
                         QString::fromUtf8(vk->getLowerBound()),
                         QString::fromUtf8(vk->getUpperBound()),
                         modules);
+            QString chapterTitle  = QString(vk->getBookName()) + " " + QString::number(vk->getChapter());
+            text.replace("#CHAPTERTITLE#", chapterTitle);
         } else { // no range supported
             text = render->renderSingleKey(key->key(), modules);
         }
     }
-    util::tool::savePlainFile(filename, text, false, getCodec(format));
+    util::tool::savePlainFile(filename, text, getCodec(format));
     return true;
 }
 
@@ -129,7 +133,7 @@ bool CExportManager::saveKeyList(sword::ListKey const & l,
     }
 
     QString const text = newRenderer(format, addText)->renderKeyTree(tree);
-    util::tool::savePlainFile(filename, text, false, getCodec(format));
+    util::tool::savePlainFile(filename, text, getCodec(format));
     closeProgressDialog();
     return true;
 }
@@ -159,7 +163,7 @@ bool CExportManager::saveKeyList(QList<CSwordKey *> const & list,
     };
 
     QString const text = newRenderer(format, addText)->renderKeyTree(tree);
-    util::tool::savePlainFile(filename, text, false, getCodec(format));
+    util::tool::savePlainFile(filename, text, getCodec(format));
     closeProgressDialog();
     return true;
 }
@@ -403,26 +407,23 @@ bool CExportManager::printKeyList(QStringList const & list,
     return true;
 }
 
-/** Returns the string for the filedialogs to show the correct files. */
-const QString CExportManager::filterString( const Format format ) {
-    QString const allFiles = QObject::tr("All files") + QString(" (*.*)");
-    switch (format) {
-        case HTML:
-            return allFiles + QObject::tr("HTML files")
-                            + QString(" (*.html *.htm);;");
-        case Text:
-            return allFiles + QObject::tr("Text files") + QString(" (*.txt);;");
-        default:
-            return allFiles;
-    }
-}
-
 /** Returns a filename to save a file. */
 const QString CExportManager::getSaveFileName(const Format format) {
+    QString filter;
+    switch (format) {
+        case HTML:
+            filter = QObject::tr("HTML files") + " (*.html *.htm);;";
+            break;
+        case Text:
+            filter = QObject::tr("Text files") + " (*.txt);;";
+            break;
+    }
+    filter += QObject::tr("All files") + " (*)";
+
     return QFileDialog::getSaveFileName(nullptr,
                                         QObject::tr("Save file"),
                                         "",
-                                        filterString(format),
+                                        filter,
                                         nullptr);
 }
 
