@@ -2,10 +2,11 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
@@ -15,8 +16,8 @@
 #include <memory>
 #include <QList>
 #include <QString>
-#include "backend/btglobal.h"
-#include "backend/config/btconfig.h"
+#include "../backend/btglobal.h"
+#include "../backend/config/btconfig.h"
 
 
 class CSwordKey;
@@ -40,14 +41,15 @@ public: /* Types: */
 public: /* Methods: */
 
     CExportManager(const bool showProgress = true,
-                   const QString &progressLabel = QString::null,
+                   const QString &progressLabel = QString(),
                    const FilterOptions &filterOptions = btConfig().getFilterOptions(),
                    const DisplayOptions &displayOptions = btConfig().getDisplayOptions());
     ~CExportManager();
 
     bool saveKey(CSwordKey const * const key,
                  Format const format,
-                 bool const addText);
+                 bool const addText,
+                 const BtConstModuleList& modules);
 
     bool saveKeyList(sword::ListKey const & list,
                      CSwordModuleInfo const * const module,
@@ -100,9 +102,6 @@ public: /* Methods: */
 
 protected: /* Methods: */
 
-    /** \returns the string for the filedialogs to show the correct files.*/
-    const QString filterString(Format const format);
-
     /** \returns a filename to save a file. */
     const QString getSaveFileName(Format const format);
 
