@@ -24,7 +24,7 @@ class CReadDisplay;
 class QAction;
 class QSize;
 class BibleTime;
-class QTextBrowser;
+class BtTextBrowser;
 
 namespace InfoDisplay {
 
@@ -60,7 +60,7 @@ private:
 private: /* Fields: */
 
     CReadDisplay * m_htmlPart;
-    QTextBrowser * m_textBrowser;
+    BtTextBrowser * m_textBrowser;
     BibleTime * m_mainWindow;
 
 };
