@@ -1,21 +1,24 @@
 /*********
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
+*
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
-#include "frontend/display/btfindwidget.h"
+#include "btfindwidget.h"
 
-#include "QCheckBox"
-#include "QHBoxLayout"
-#include "QLineEdit"
-#include "QSpacerItem"
-#include "QToolButton"
-#include "util/btconnect.h"
-#include "util/cresmgr.h"
+#include <QCheckBox>
+#include <QHBoxLayout>
+#include <QLineEdit>
+#include <QSpacerItem>
+#include <QToolButton>
+#include "../../util/btconnect.h"
+#include "../../util/cresmgr.h"
 
 
 namespace {
