@@ -1,24 +1,26 @@
 /*********
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
+*
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
-#include "frontend/display/cdisplay.h"
+#include "cdisplay.h"
 
 #include <QApplication>
 #include <QClipboard>
 #include <QFileDialog>
 #include <QMenu>
 #include <QTimer>
-#include "backend/managers/referencemanager.h"
-#include "frontend/display/bthtmlreaddisplay.h"
-#include "frontend/display/chtmlwritedisplay.h"
-#include "frontend/display/cplainwritedisplay.h"
-#include "util/tool.h"
+#include "../../backend/managers/referencemanager.h"
+#include "../../util/tool.h"
+#include "../btcopybyreferencesdialog.h"
+#include "../displaywindow/cdisplaywindow.h"
 
 
 CDisplayConnections::CDisplayConnections( CDisplay* display ) : m_display(display) {}
@@ -59,6 +61,14 @@ void CDisplayConnections::copySelection() {
     m_display->copy(CDisplay::PlainText, CDisplay::SelectedText);
 }
 
+void CDisplayConnections::copySelectedText() {
+   m_display->copySelectedText();
+}
+
+void CDisplayConnections::copyByReferences() {
+   m_display->copyByReferences();
+}
+
 void CDisplayConnections::printAll(const DisplayOptions &displayOptions,
                                    const FilterOptions &filterOptions)
 {
@@ -88,7 +98,7 @@ void CDisplayConnections::saveAnchorWithText() {
 }
 
 void CDisplayConnections::clear() {
-    m_display->setText(QString::null);
+    m_display->setText(QString());
 }
 
 void CDisplayConnections::openFindTextDialog() {
@@ -100,32 +110,48 @@ void CDisplayConnections::openFindTextDialog() {
 
 
 CDisplay::CDisplay(CDisplayWindow* parent) :
-        m_parentWindow(parent),
-        m_connections( new CDisplayConnections( this ) ),
-        m_popup(nullptr) {}
+    m_parentWindow(parent),
+    m_connections( new CDisplayConnections( this ) ),
+    m_popup(nullptr) {}
 
 CDisplay::~CDisplay() {
     delete m_connections;
 }
 
+void CDisplay::scrollToKey(CSwordKey* /* key */ ) {
+    // Implemented for some subclases
+}
+
+void CDisplay::setModules(const QStringList& /* modules */) {
+    // Implemented for some subclases
+}
+
 bool CDisplay::copy( const CDisplay::TextType format, const CDisplay::TextPart part  ) {
     QApplication::clipboard()->setText( this->text(format, part) );
     return true;
 }
 
+void CDisplay::copySelectedText() {
+    parentWindow()->copySelectedText();
+}
+
+void CDisplay::copyByReferences() {
+    parentWindow()->copyByReferences();
+}
+
 bool CDisplay::save( const CDisplay::TextType format, const CDisplay::TextPart part ) {
     //  qWarning("CDisplay::save( const CDisplay::TextType format, const CDisplay::TextPart part  )");
     const QString content = text(format, part);
-    QString filter = QString::null;
-
+    QString filter;
     switch (format) {
-        case HTMLText:
-            filter = QObject::tr("HTML files") + QString(" (*.html *.htm);;") + QObject::tr("All files") + QString(" (*.*)");
-            break;
-        case PlainText:
-            filter = QObject::tr("Text files") + QString(" (*.txt);;") + QObject::tr("All files") + QString(" (*.*)");
-            break;
+    case HTMLText:
+        filter = QObject::tr("HTML files") + " (*.html *.htm);;";
+        break;
+    case PlainText:
+        filter = QObject::tr("Text files") + " (*.txt);;";
+        break;
     }
+    filter += QObject::tr("All files") + " (*)";
 
     const QString filename = QFileDialog::getSaveFileName(nullptr, QObject::tr("Save document ..."), "", filter);
 
