@@ -84,7 +84,7 @@ void BtTextFilter::splitText(const QString& text) {
 
 void BtTextFilter::fixDoubleBR() {
     for (int index = 2; index < m_parts.count(); ++index) {
-        QRegExp rx("<br\\s+/>");
+        QRegExp rx("<br\\s*/>");
         if (m_parts.at(index).contains(rx) && m_parts.at(index-2).contains(rx))
             m_parts[index] = "";
     }
@@ -117,7 +117,7 @@ int BtTextFilter::rewriteFootnoteAsLink(int i, const QString& part) {
 // Output:        <a href="sword://Bible/ESV2011/Luke 11:29||name=Luke11_29">
 
 int BtTextFilter::rewriteHref(int i, const QString& part) {
-    QRegExp rx1("<a\\s(\\w+)=\"([\\s\\S]*)\"\\s(\\w+)=\"([\\s\\S]*)\"");
+    QRegExp rx1("<a\\s+(\\w+)=\"([^\"]*)\"\\s+(\\w+)=\"([^\"]*)\"");
     rx1.setMinimal(false);
     int pos1 = rx1.indexIn(part);
     if (pos1 >= 0 && rx1.captureCount() == 4) {
@@ -155,7 +155,7 @@ int BtTextFilter::rewriteLemmaOrMorphAsLink(int i, const QString& part) {
     QString refText = m_parts.at(i+1);
     QString url = "sword://lemmamorph/" + value + "/" + refText;
     QString newEntry;
-    newEntry = "<a id=lemmamorph href=\"" + url + "\">";
+    newEntry = "<a id=\"lemmamorph\" href=\"" + url + "\">";
     m_parts[i] = newEntry;
     m_parts[i+2] = "</a>";
     return 3;
