@@ -2,18 +2,19 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
 #ifndef BT_MODULECHOOSERBAR
 #define BT_MODULECHOOSERBAR
 
+#include "../../backend/drivers/cswordmoduleinfo.h"
 #include "btwindowmodulechooser.h"
-#include "backend/drivers/cswordmoduleinfo.h"
 #include <QToolBar>
 #include <QStringList>
 
