@@ -1,9 +1,12 @@
 /*********
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
+*
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
@@ -18,10 +21,10 @@
 #include <QStringList>
 #include <QToolButton>
 #include <QWidget>
+#include "../../util/btconnect.h"
+#include "../../util/btmodules.h"
 #include "bttextwindowheaderwidget.h"
 #include "clexiconreadwindow.h"
-#include "util/btconnect.h"
-#include "util/btmodules.h"
 
 
 BtTextWindowHeader::BtTextWindowHeader(CSwordModuleInfo::ModuleType modtype,
@@ -46,13 +49,12 @@ void BtTextWindowHeader::slotBackendModulesChanged() {
 
     adjustWidgetCount();
 
-    //recreate all widgets from scratch
     int const leftLikeModules = leftLikeParallelModules(m_modules);
     for (int i = 0; i < m_widgetList.count(); i++)
-        m_widgetList.at(i)->recreateWidget(m_modules,
-                                           m_modules.at(i),
-                                           i,
-                                           leftLikeModules);
+        m_widgetList.at(i)->updateWidget(m_modules,
+                                         m_modules.at(i),
+                                         i,
+                                         leftLikeModules);
 }
 
 void BtTextWindowHeader::slotWindowModulesChanged() {
@@ -92,7 +94,8 @@ void BtTextWindowHeader::adjustWidgetCount(bool adjustToZero) {
 }
 
 BtTextWindowHeaderWidget* BtTextWindowHeader::addWidget() {
-    BtTextWindowHeaderWidget* w = new BtTextWindowHeaderWidget(this, m_moduleType);
+    BtTextWindowHeaderWidget * const w =
+            new BtTextWindowHeaderWidget(m_moduleType, this);
     layout()->addWidget(w);
     m_widgetList.append(w);
 
