@@ -1,30 +1,33 @@
 /*********
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
+*
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
-#include "frontend/displaywindow/cbookreadwindow.h"
+#include "cbookreadwindow.h"
 
 #include <QAction>
 #include <QMenu>
 #include <QSplitter>
 #include <QToolBar>
-#include "bibletime.h"
-#include "backend/keys/cswordtreekey.h"
-#include "frontend/display/bthtmlreaddisplay.h"
-#include "frontend/displaywindow/bttoolbarpopupaction.h"
-#include "frontend/displaywindow/btactioncollection.h"
-#include "frontend/displaywindow/btmodulechooserbar.h"
-#include "frontend/displaywindow/btdisplaysettingsbutton.h"
-#include "frontend/keychooser/cbooktreechooser.h"
-#include "util/btassert.h"
-#include "util/btconnect.h"
-#include "util/cresmgr.h"
-#include "util/tool.h"
+#include "../../backend/keys/cswordtreekey.h"
+#include "../../util/btassert.h"
+#include "../../util/btconnect.h"
+#include "../../util/cresmgr.h"
+#include "../../util/tool.h"
+#include "../bibletime.h"
+#include "../display/btmodelviewreaddisplay.h"
+#include "../keychooser/cbooktreechooser.h"
+#include "btactioncollection.h"
+#include "btdisplaysettingsbutton.h"
+#include "btmodulechooserbar.h"
+#include "bttoolbarpopupaction.h"
 
 
 void CBookReadWindow::applyProfileSettings(const QString & windowGroup) {
@@ -64,7 +67,7 @@ void CBookReadWindow::insertKeyboardActions( BtActionCollection* const a ) {
     QAction* qaction;
 
     qaction = new QAction( /* QIcon(CResMgr::displaywindows::bookWindow::toggleTree::icon), */
-        tr("Toggle tree view"), a);
+                           tr("Toggle tree view"), a);
     qaction->setCheckable(true);
     // qaction->setShortcut(CResMgr::displaywindows::bookWindow::toggleTree::accel);
     a->addAction("toggleTree", qaction);
@@ -86,8 +89,13 @@ void CBookReadWindow::initConnections() {
 void CBookReadWindow::initView() {
     QSplitter* splitter = new QSplitter(this);
     m_treeChooser = new CBookTreeChooser(modules(), history(), key(), splitter);
-    setDisplayWidget(new BtHtmlReadDisplay(this, splitter));
+    setDisplayWidget(new BtModelViewReadDisplay(this, splitter));
     m_treeChooser->hide();
+    splitter->setStretchFactor(1,3);
+
+    BtModelViewReadDisplay* disp = dynamic_cast<BtModelViewReadDisplay*>(displayWidget());
+    if (disp)
+        disp->setModules(getModuleList());
 
     // Create Navigation toolbar
     setMainToolBar( new QToolBar(this) );
@@ -127,7 +135,7 @@ void CBookReadWindow::initToolbars() {
     buttonsToolBar()->addWidget(button);  // Display settings
     // Search:
     buttonsToolBar()->addAction(
-            &actionCollection()->action(
+                &actionCollection()->action(
                     CResMgr::displaywindows::general::search::actionName));
 }
 
@@ -152,7 +160,7 @@ void CBookReadWindow::setupMainWindowToolBars() {
     btMainWindow()->toolsToolBar()->addWidget(button);  // Display settings
     // Search:
     btMainWindow()->toolsToolBar()->addAction(
-            &actionCollection()->action(
+                &actionCollection()->action(
                     CResMgr::displaywindows::general::search::actionName));
 }
 
