@@ -1,28 +1,31 @@
 /*********
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
+*
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
-#include "frontend/displaywindow/ccommentaryreadwindow.h"
+#include "ccommentaryreadwindow.h"
 
 #include <QAction>
 #include <QIcon>
 #include <QMenu>
 #include <QToolBar>
-#include "backend/keys/cswordversekey.h"
-#include "bibletime.h"
-#include "bibletimeapp.h"
-#include "frontend/display/cdisplay.h"
-#include "frontend/display/creaddisplay.h"
-#include "frontend/displaywindow/btactioncollection.h"
-#include "frontend/displaywindow/btmodulechooserbar.h"
-#include "frontend/keychooser/ckeychooser.h"
-#include "util/btconnect.h"
-#include "util/cresmgr.h"
+#include "../../backend/keys/cswordversekey.h"
+#include "../../util/btconnect.h"
+#include "../../util/cresmgr.h"
+#include "../bibletime.h"
+#include "../bibletimeapp.h"
+#include "../display/cdisplay.h"
+#include "../display/creaddisplay.h"
+#include "../keychooser/ckeychooser.h"
+#include "btactioncollection.h"
+#include "btmodulechooserbar.h"
 
 
 void CCommentaryReadWindow::insertKeyboardActions(BtActionCollection* const a) {
