@@ -1,13 +1,16 @@
 /*********
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
+*
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
-#include "frontend/displaywindow/cdisplaywindow.h"
+#include "cdisplaywindow.h"
 
 #include <QCloseEvent>
 #include <QDebug>
@@ -15,19 +18,19 @@
 #include <QMenu>
 #include <QStringList>
 #include <QWidget>
-#include "backend/config/btconfig.h"
-#include "backend/keys/cswordkey.h"
-#include "bibletime.h"
-#include "bibletimeapp.h"
-#include "frontend/cmdiarea.h"
-#include "frontend/display/cdisplay.h"
-#include "frontend/displaywindow/bttoolbarpopupaction.h"
-#include "frontend/displaywindow/btmodulechooserbar.h"
-#include "frontend/displaywindow/btdisplaysettingsbutton.h"
-#include "frontend/keychooser/ckeychooser.h"
-#include "frontend/keychooser/bthistory.h"
-#include "frontend/searchdialog/csearchdialog.h"
-#include "util/cresmgr.h"
+#include "../../backend/config/btconfig.h"
+#include "../../backend/keys/cswordkey.h"
+#include "../../util/cresmgr.h"
+#include "../bibletime.h"
+#include "../bibletimeapp.h"
+#include "../cmdiarea.h"
+#include "../display/cdisplay.h"
+#include "../keychooser/ckeychooser.h"
+#include "../keychooser/bthistory.h"
+#include "../searchdialog/csearchdialog.h"
+#include "bttoolbarpopupaction.h"
+#include "btmodulechooserbar.h"
+#include "btdisplaysettingsbutton.h"
 
 
 namespace {
@@ -43,26 +46,26 @@ inline QWidget * getProfileWindow(QWidget * w) {
 
 
 CDisplayWindow::CDisplayWindow(const QList<CSwordModuleInfo *> & modules, CMDIArea * parent)
-        : QMainWindow(parent),
-        m_actionCollection(nullptr),
-        m_mdi(parent),
-        m_keyChooser(nullptr),
-        m_swordKey(nullptr),
-        m_isReady(false),
-        m_moduleChooserBar(nullptr),
-        m_mainToolBar(nullptr),
-        m_buttonsToolBar(nullptr),
-        m_formatToolBar(nullptr),
-        m_headerBar(nullptr),
-        m_popupMenu(nullptr),
-        m_displayWidget(nullptr),
-        m_history(nullptr) {
+    : QMainWindow(parent),
+      m_actionCollection(nullptr),
+      m_mdi(parent),
+      m_keyChooser(nullptr),
+      m_swordKey(nullptr),
+      m_isReady(false),
+      m_moduleChooserBar(nullptr),
+      m_mainToolBar(nullptr),
+      m_buttonsToolBar(nullptr),
+      m_headerBar(nullptr),
+      m_popupMenu(nullptr),
+      m_displayWidget(nullptr),
+      m_history(nullptr) {
 
     // Cannot delete on close. QMdiSubWindow and this window work
     // as pairs. They must be deleted in a specific order.
     // QMdiSubWindow handles this procedure.
     //setAttribute(Qt::WA_DeleteOnClose);
 
+    setObjectName("CDisplayWindow");
     m_actionCollection = new BtActionCollection(this);
     setModules(modules);
 
@@ -79,8 +82,6 @@ CDisplayWindow::CDisplayWindow(const QList<CSwordModuleInfo *> & modules, CMDIAr
                SLOT(slotShowToolButtons(bool)));
     BT_CONNECT(mainwindow, SIGNAL(toggledTextWindowModuleChooser(bool)),
                SLOT(slotShowModuleChooser(bool)));
-    BT_CONNECT(mainwindow, SIGNAL(toggledTextWindowFormatToolbar(bool)),
-               SLOT(slotShowFormatToolBar(bool)));
 }
 
 CDisplayWindow::~CDisplayWindow() {
@@ -100,14 +101,11 @@ void CDisplayWindow::setToolBarsHidden() {
         m_buttonsToolBar->setHidden(true);
     if (m_moduleChooserBar)
         m_moduleChooserBar->setHidden(true);
-    if (m_formatToolBar)
-        m_formatToolBar->setHidden(true);
 }
 void CDisplayWindow::clearMainWindowToolBars() {
     // Clear main window toolbars, except for works toolbar
     btMainWindow()->navToolBar()->clear();
     btMainWindow()->toolsToolBar()->clear();
-    btMainWindow()->formatToolBar()->clear();
 }
 
 void CDisplayWindow::windowActivated() {
@@ -118,7 +116,7 @@ void CDisplayWindow::windowActivated() {
 /** Returns the right window caption. */
 const QString CDisplayWindow::windowCaption() {
     if (!m_modules.count()) {
-        return QString::null;
+        return QString();
     }
 
     return QString(key()->key()).append(" (").append(m_modules.join(" | ")).append(")");
@@ -213,6 +211,10 @@ void CDisplayWindow::insertKeyboardActions( BtActionCollection* a ) {
     actn->setShortcut(QKeySequence::Copy);
     a->addAction("copySelectedText", actn);
 
+    actn = new QAction(QIcon(), tr("Copy by references..."), a);
+    actn->setShortcut(Qt::CTRL + Qt::Key_R);
+    a->addAction("copyByReferences", actn);
+
     actn = new QAction(QIcon(), tr("Find..."), a);
     actn->setShortcut(QKeySequence::Find);
     a->addAction("findText", actn);
@@ -221,24 +223,32 @@ void CDisplayWindow::insertKeyboardActions( BtActionCollection* a ) {
     actn->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_L));
     a->addAction("openLocation", actn);
 
+    actn = new QAction(QIcon(), tr("Page down"), a);
+    actn->setShortcut(QKeySequence(Qt::Key_PageDown));
+    a->addAction("pageDown", actn);
+
+    actn = new QAction(QIcon(), tr("Page up"), a);
+    actn->setShortcut(QKeySequence(Qt::Key_PageUp));
+    a->addAction("pageUp", actn);
+
     actn = new QAction(CResMgr::displaywindows::general::search::icon(),
                        tr("Search with works of this window"), a);
     actn->setShortcut(CResMgr::displaywindows::general::search::accel);
     a->addAction(CResMgr::displaywindows::general::search::actionName, actn);
 
     BtToolBarPopupAction* action = new BtToolBarPopupAction(
-        CResMgr::displaywindows::general::backInHistory::icon(),
-        tr("Back in history"),
-        a
-    );
+                CResMgr::displaywindows::general::backInHistory::icon(),
+                tr("Back in history"),
+                a
+                );
     action->setShortcut(CResMgr::displaywindows::general::backInHistory::accel);
     a->addAction(CResMgr::displaywindows::general::backInHistory::actionName, action);
 
     action = new BtToolBarPopupAction(
-        CResMgr::displaywindows::general::forwardInHistory::icon(),
-        tr("Forward in history"),
-        a
-    );
+                CResMgr::displaywindows::general::forwardInHistory::icon(),
+                tr("Forward in history"),
+                a
+                );
     action->setShortcut(CResMgr::displaywindows::general::forwardInHistory::accel);
     a->addAction(CResMgr::displaywindows::general::forwardInHistory::actionName, action);
 }
@@ -246,20 +256,26 @@ void CDisplayWindow::insertKeyboardActions( BtActionCollection* a ) {
 void CDisplayWindow::initActions() {
     BtActionCollection* ac = actionCollection();
 
-    CDisplayWindow::insertKeyboardActions(ac);
+    insertKeyboardActions(ac);
 
     namespace DWG = CResMgr::displaywindows::general;
     initAction(DWG::search::actionName,
                this,
                &CDisplayWindow::slotSearchInModules);
     initAddAction("openLocation", this, &CDisplayWindow::setFocusKeyChooser);
+    initAddAction("pageDown", this, &CDisplayWindow::pageDown);
+    initAddAction("pageUp", this, &CDisplayWindow::pageUp);
+
     CDisplayConnections * const conn = displayWidget()->connectionsProxy();
     initAddAction("selectAll",
                   conn,
                   &CDisplayConnections::selectAll);
     initAddAction("copySelectedText",
                   conn,
-                  &CDisplayConnections::copySelection);
+                  &CDisplayConnections::copySelectedText);
+    initAddAction("copyByReferences",
+                  conn,
+                  &CDisplayConnections::copyByReferences);
     initAddAction("findText",
                   conn,
                   &CDisplayConnections::openFindTextDialog);
@@ -288,6 +304,8 @@ void CDisplayWindow::reload(CSwordBackend::SetupChangedReason) {
         return;
     }
 
+    displayWidget()->reloadModules();
+
     if (CKeyChooser * const kc = keyChooser())
         kc->setModules(modules(), false);
 
@@ -299,23 +317,27 @@ void CDisplayWindow::reload(CSwordBackend::SetupChangedReason) {
 }
 
 void CDisplayWindow::slotAddModule(int index, QString module) {
+    BT_ASSERT(index <= m_modules.size());
     m_modules.insert(index, module);
+    displayWidget()->setModules(m_modules);
     lookup();
     modulesChanged();
     emit sigModuleListChanged();
 }
 
 void CDisplayWindow::slotReplaceModule(int index, QString newModule) {
-    qDebug() << "CDisplayWindow::slotReplaceModule" << m_modules.at(index) << "with" << newModule;
+    BT_ASSERT(index < m_modules.size());
     m_modules.replace(index, newModule);
-    qDebug() << "window's new module list:" << m_modules;
+    displayWidget()->setModules(m_modules);
     lookup();
     modulesChanged();
     emit sigModuleListChanged();
 }
 
 void CDisplayWindow::slotRemoveModule(int index) {
+    BT_ASSERT(index < m_modules.size());
     m_modules.removeAt(index);
+    displayWidget()->setModules(m_modules);
     lookup();
     modulesChanged();
     emit sigModuleListChanged();
@@ -324,6 +346,7 @@ void CDisplayWindow::slotRemoveModule(int index) {
 /** Sets the new display options for this window. */
 void CDisplayWindow::setDisplayOptions(const DisplayOptions &displayOptions) {
     m_displayOptions = displayOptions;
+    displayWidget()->setDisplayOptions(displayOptions);
     emit sigDisplayOptionsChanged(m_displayOptions);
 }
 
@@ -448,12 +471,6 @@ void CDisplayWindow::setButtonsToolBar( QToolBar* bar ) {
     m_buttonsToolBar = bar;
 }
 
-/** Setup the Format toolbar. */
-void CDisplayWindow::setFormatToolBar( QToolBar* bar ) {
-    prepareToolBar(bar, tr("Format"), true );
-    m_formatToolBar = bar;
-}
-
 /** Sets the display settings button. */
 void CDisplayWindow::setDisplaySettingsButton(BtDisplaySettingsButton *button) {
     BT_CONNECT(this,   SIGNAL(sigDisplayOptionsChanged(DisplayOptions const &)),
@@ -495,11 +512,6 @@ void CDisplayWindow::slotShowModuleChooser(bool show) {
         moduleChooserBar()->setVisible(show);
 }
 
-void CDisplayWindow::slotShowFormatToolBar(bool show) {
-    if (formatToolBar())
-        formatToolBar()->setVisible(show);
-}
-
 /** Lookup the current key. Used to refresh the display. */
 void CDisplayWindow::lookup() {
     lookupSwordKey( key() );
@@ -597,3 +609,10 @@ void CDisplayWindow::setFocusKeyChooser() {
     }
 }
 
+void CDisplayWindow::pageDown() {
+
+}
+
+void CDisplayWindow::pageUp() {
+
+}
