@@ -1,23 +1,26 @@
 /*********
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
+*
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
-#include "frontend/keychooser/cbooktreechooser.h"
+#include "cbooktreechooser.h"
 
 #include <QApplication>
 #include <QHBoxLayout>
 #include <QTreeWidget>
 #include <QTreeWidgetItem>
-#include "backend/config/btconfig.h"
-#include "backend/drivers/cswordbookmoduleinfo.h"
-#include "backend/keys/cswordtreekey.h"
-#include "frontend/keychooser/bthistory.h"
-#include "util/btconnect.h"
+#include "../../backend/config/btconfig.h"
+#include "../../backend/drivers/cswordbookmoduleinfo.h"
+#include "../../backend/keys/cswordtreekey.h"
+#include "../../util/btconnect.h"
+#include "bthistory.h"
 
 
 CBookTreeChooser::CBookTreeChooser(const BtConstModuleList & modules,
