@@ -1,23 +1,26 @@
 /*********
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
+*
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
-#include "frontend/keychooser/clexiconkeychooser.h"
+#include "clexiconkeychooser.h"
 
 #include <algorithm>
 #include <QHBoxLayout>
-#include "backend/drivers/cswordlexiconmoduleinfo.h"
-#include "backend/keys/cswordldkey.h"
-#include "frontend/keychooser/bthistory.h"
-#include "frontend/keychooser/ckeychooserwidget.h"
-#include "frontend/keychooser/cscrollbutton.h"
-#include "util/btconnect.h"
-#include "util/cresmgr.h"
+#include "../../backend/drivers/cswordlexiconmoduleinfo.h"
+#include "../../backend/keys/cswordldkey.h"
+#include "../../util/btconnect.h"
+#include "../../util/cresmgr.h"
+#include "bthistory.h"
+#include "ckeychooserwidget.h"
+#include "cscrollbutton.h"
 
 
 CLexiconKeyChooser::CLexiconKeyChooser(const BtConstModuleList & modules,
