@@ -2,10 +2,11 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
@@ -15,8 +16,8 @@
 #include <QWidget>
 
 #include <QTimer>
-#include "backend/drivers/cswordbiblemoduleinfo.h"
-#include "frontend/keychooser/cscrollerwidgetset.h"
+#include "../../../backend/drivers/cswordbiblemoduleinfo.h"
+#include "../cscrollerwidgetset.h"
 
 
 class BtDropdownChooserButton;
@@ -32,7 +33,7 @@ class BtBibleKeyWidget : public QWidget  {
                          CSwordVerseKey *key, QWidget *parent = nullptr,
                          const char *name = nullptr);
 
-        ~BtBibleKeyWidget();
+        ~BtBibleKeyWidget() override;
         bool setKey(CSwordVerseKey* key);
         void setModule(const CSwordBibleModuleInfo *m = nullptr);
         bool eventFilter(QObject *o, QEvent *e) override;
