@@ -2,10 +2,11 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
 *
-* Copyright 1999-2014 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
@@ -29,9 +30,9 @@ class BtVerseKeyMenu : public QMenu {
     public:
         BtVerseKeyMenu(QWidget* parent);
     protected:
-        virtual void mouseReleaseEvent(QMouseEvent* event);
+        void mouseReleaseEvent(QMouseEvent* event) override;
         /** Frees the mouse button release after the delay has elapsed.*/
-        virtual void timerEvent(QTimerEvent* event);
+        void timerEvent(QTimerEvent* event) override;
     private slots:
         /** Starts the delay timer for the first mouse button release.*/
         void startFirstClickDelayTimer();
