@@ -1,24 +1,27 @@
 /*********
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
+*
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
-#include "frontend/searchdialog/analysis/csearchanalysisscene.h"
+#include "csearchanalysisscene.h"
 
 #include <QApplication>
 #include <QFileDialog>
 #include <QHashIterator>
 #include <QTextCodec>
 #include <QTextDocument>
-#include "backend/keys/cswordversekey.h"
-#include "frontend/searchdialog/analysis/csearchanalysisitem.h"
-#include "frontend/searchdialog/analysis/csearchanalysislegenditem.h"
-#include "frontend/searchdialog/csearchdialog.h"
-#include "util/tool.h"
+#include "../../../backend/keys/cswordversekey.h"
+#include "../../../util/tool.h"
+#include "../csearchdialog.h"
+#include "csearchanalysisitem.h"
+#include "csearchanalysislegenditem.h"
 
 // Sword includes
 #include <listkey.h>
@@ -165,8 +168,12 @@ void CSearchAnalysisScene::reset() {
 
 /** No descriptions */
 void CSearchAnalysisScene::slotResized() {
-    m_scaleFactor = static_cast<double>(height() - UPPER_BORDER - LOWER_BORDER - BAR_LOWER_BORDER - 100 - (m_results.count() - 1) * BAR_DELTAY)
-                    / static_cast<double>(m_maxCount);
+    if (m_maxCount <= 0) {
+        m_scaleFactor = 0.0;
+    } else {
+        m_scaleFactor = static_cast<double>(height() - UPPER_BORDER - LOWER_BORDER - BAR_LOWER_BORDER - 100 - (m_results.count() - 1) * BAR_DELTAY)
+                        / static_cast<double>(m_maxCount);
+    }
     QHashIterator<QString, CSearchAnalysisItem*> it( m_itemList );
     while ( it.hasNext() ) {
         it.next();
@@ -227,10 +234,13 @@ unsigned int CSearchAnalysisScene::getCount(const QString &book,
 void CSearchAnalysisScene::saveAsHTML() {
     using RCI = CSwordModuleSearch::Results::const_iterator;
 
-    const QString fileName = QFileDialog::getSaveFileName(nullptr,
-                                                          tr("Save Search Analysis"),
-                                                          QString::null,
-                                                          tr("XHTML files (*.html *.HTML *.HTM *.htm);;All files (*)"));
+    auto const fileName =
+            QFileDialog::getSaveFileName(
+                nullptr,
+                tr("Save Search Analysis"),
+                QString(),
+                QObject::tr("HTML files") +" (*.html *.htm);;"
+                + QObject::tr("All files") + " (*)");
     if (fileName.isEmpty())
         return;
 
@@ -302,7 +312,7 @@ void CSearchAnalysisScene::saveAsHTML() {
     text += tr("Created by <a href=\"http://www.bibletime.info/\">BibleTime</a>");
     text += "</p></body></html>";
 
-    util::tool::savePlainFile(fileName, text, true, QTextCodec::codecForName("UTF8"));
+    util::tool::savePlainFile(fileName, text, QTextCodec::codecForName("UTF-8"));
 }
 
 void CSearchAnalysisScene::resizeHeight(int height) {
