@@ -16,12 +16,12 @@
 #include <QList>
 #include <QSplitter>
 #include <QStringList>
-#include <QTextBrowser>
 #include <QWidget>
 #include "../../backend/managers/cswordbackend.h"
 #include "../../backend/cswordmodulesearch.h"
 #include "../display/creaddisplay.h"
 #include "analysis/csearchanalysisdialog.h"
+#include "../bttextbrowser.h"
 
 
 namespace Search {
@@ -182,7 +182,7 @@ class BtSearchResultArea : public QWidget {
         CSearchResultView* m_resultListBox;
 
         QFrame *m_displayFrame;
-        QTextBrowser* m_previewDisplay;
+        BtTextBrowser * m_previewDisplay;
 
         QSplitter *m_mainSplitter;
         QSplitter *m_resultListSplitter;
