@@ -1,20 +1,23 @@
 /*********
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
+*
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
-#include "frontend/searchdialog/btsearchsyntaxhelpdialog.h"
+#include "btsearchsyntaxhelpdialog.h"
 
 #include <QDesktopServices>
 #include <QDialogButtonBox>
+#include <QTextBrowser>
 #include <QVBoxLayout>
-#include <frontend/btwebengineview.h>
-#include "frontend/messagedialog.h"
-#include "util/btconnect.h"
+#include "../../util/btconnect.h"
+#include "../messagedialog.h"
 
 
 namespace Search {
@@ -26,12 +29,13 @@ BtSearchSyntaxHelpDialog::BtSearchSyntaxHelpDialog(QWidget *parent, Qt::WindowFl
 
     QVBoxLayout *l = new QVBoxLayout;
 
-    m_webView = new BtWebEngineView(this);
-    BtWebEnginePage * page = new BtWebEnginePage(this);
-    m_webView->setPage(page);
-    BT_CONNECT(m_webView->btPage(), SIGNAL(linkClicked(QUrl)),
+    m_textBrowser = new QTextBrowser(this);
+    QFont font = m_textBrowser->font();
+    font.setPointSize(font.pointSize()+2);
+    m_textBrowser->setFont(font);
+    BT_CONNECT(m_textBrowser, SIGNAL(anchorClicked(QUrl)),
                this,      SLOT(linkClicked(QUrl)));
-    l->addWidget(m_webView);
+    l->addWidget(m_textBrowser);
 
     m_buttons = new QDialogButtonBox(QDialogButtonBox::Close, Qt::Horizontal, this);
     BT_CONNECT(m_buttons, SIGNAL(rejected()), this, SLOT(reject()));
@@ -211,7 +215,7 @@ void BtSearchSyntaxHelpDialog::retranslateUi() {
                 .arg("http://lucene.apache.org/java/1_4_3/queryparsersyntax.html");
     html += "</p></body></html>";
 
-    m_webView->setHtml(html);
+    m_textBrowser->setHtml(html);
 
     message::prepareDialogBox(m_buttons);
 }
