@@ -2,10 +2,11 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
@@ -15,7 +16,7 @@
 #include <QTreeWidget>
 
 #include <QLabel>
-#include "frontend/searchdialog/btsearchresultarea.h"
+#include "btsearchresultarea.h"
 
 
 class CSwordModuleInfo;
@@ -32,7 +33,7 @@ class CModuleResultView : public QTreeWidget {
         Q_OBJECT
     public:
         CModuleResultView(QWidget* parent);
-        ~CModuleResultView();
+        ~CModuleResultView() override;
 
         /**
           Setups the tree using the given list of modules.
