@@ -1,13 +1,16 @@
 /*********
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
+*
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
-#include "frontend/searchdialog/csearchdialog.h"
+#include "csearchdialog.h"
 
 #include <QDebug>
 #include <QDialogButtonBox>
@@ -19,18 +22,19 @@
 #include <QRegExp>
 #include <QVBoxLayout>
 #include <QWidget>
-#include "backend/config/btconfig.h"
-#include "backend/cswordmodulesearch.h"
-#include "backend/keys/cswordkey.h"
-#include "backend/keys/cswordversekey.h"
-#include "bibletimeapp.h"
-#include "frontend/btmoduleindexdialog.h"
-#include "frontend/searchdialog/btsearchoptionsarea.h"
-#include "frontend/searchdialog/btsearchresultarea.h"
-#include "frontend/messagedialog.h"
-#include "util/btassert.h"
-#include "util/btconnect.h"
-#include "util/cresmgr.h"
+#include "../../backend/config/btconfig.h"
+#include "../../backend/cswordmodulesearch.h"
+#include "../../backend/keys/cswordkey.h"
+#include "../../backend/keys/cswordversekey.h"
+#include "../../util/btassert.h"
+#include "../../util/btconnect.h"
+#include "../../util/cresmgr.h"
+#include "../bibletimeapp.h"
+#include "../btmoduleindexdialog.h"
+#include "../messagedialog.h"
+#include "btindexdialog.h"
+#include "btsearchoptionsarea.h"
+#include "btsearchresultarea.h"
 
 
 namespace {
@@ -75,6 +79,12 @@ void CSearchDialog::closeDialog() {
         m_staticDialog->closeButtonClicked();
 }
 
+void CSearchDialog::manageIndexesButtonClicked() {
+
+    BtIndexDialog dlg(this);
+    dlg.exec();
+}
+
 CSearchDialog* CSearchDialog::getSearchDialog() {
     BT_ASSERT(m_staticDialog);
     return m_staticDialog;
@@ -168,10 +178,19 @@ void CSearchDialog::startSearch() {
     try {
         m_searcher.startSearch();
     } catch (...) {
+        QString msg;
+        try {
+            throw;
+        } catch (std::exception const & e) {
+            msg = e.what();
+        } catch (...) {
+            msg = tr("<UNKNOWN EXCEPTION>");
+        }
+
         message::showWarning(this,
                              tr("Search aborted"),
                              tr("An internal error occurred while executing "
-                                "your search."));
+                                "your search:<br/><br/>%1").arg(msg));
         // Re-enable the dialog:
         setEnabled(true);
         setCursor(Qt::ArrowCursor);
@@ -226,11 +245,16 @@ void CSearchDialog::initView() {
 
     QHBoxLayout* horizontalLayout = new QHBoxLayout();
 
+    QSpacerItem* spacerItem = new QSpacerItem(1, 1, QSizePolicy::Expanding, QSizePolicy::Minimum);
+    horizontalLayout->addItem(spacerItem);
+
     m_analyseButton = new QPushButton(tr("&Analyze results..."), nullptr);
     m_analyseButton->setToolTip(tr("Show a graphical analysis of the search result"));
-    QSpacerItem* spacerItem = new QSpacerItem(1, 1, QSizePolicy::Expanding, QSizePolicy::Minimum);
     horizontalLayout->addWidget(m_analyseButton);
-    horizontalLayout->addItem(spacerItem);
+
+    m_manageIndexes = new QPushButton(tr("&Manage Indexes..."), nullptr);
+    m_manageIndexes->setToolTip(tr("Recreate search indexes"));
+    horizontalLayout->addWidget(m_manageIndexes);
 
     m_closeButton = new QPushButton(this);
     m_closeButton->setText(tr("&Close"));
@@ -260,6 +284,8 @@ void CSearchDialog::initConnections() {
     BT_CONNECT(m_analyseButton, SIGNAL(clicked()),
                m_searchResultArea, SLOT(showAnalysis()));
 
+    BT_CONNECT(m_manageIndexes, SIGNAL(clicked()),
+               this, SLOT(manageIndexesButtonClicked()));
 }
 
 /** Resets the parts to the default. */
