@@ -15,15 +15,16 @@
 
 #include "btconfigdialog.h"
 
-#include <QMap>
 #include <QWidget>
+#include <vector>
 #include "../../backend/config/btconfig.h"
+#include "../../backend/managers/clanguagemgr.h"
 
 
-class BtFontChooserWidget;
 class CConfigurationDialog;
 class QCheckBox;
 class QComboBox;
+class QFontDialog;
 class QGroupBox;
 class QLabel;
 
@@ -33,7 +34,10 @@ class BtFontSettingsPage: public BtConfigDialog::Page {
 
     private: /* Types: */
 
-        using FontMap = QMap<QString, BtConfig::FontSettingsPair>;
+        struct WorkSetting {
+            CLanguageMgr::Language const & language;
+            BtConfig::FontSettingsPair settings;
+        };
 
     public: /* Methods: */
 
@@ -46,12 +50,6 @@ class BtFontSettingsPage: public BtConfigDialog::Page {
         // This slot is called when the "Use own font for language" button was clicked.
         void useOwnFontClicked(bool);
 
-        // Called when a new font in the fonts page was selected.
-        void newDisplayWindowFontSelected(const QFont &);
-
-        // Called when the combobox contents is changed
-        void newDisplayWindowFontAreaSelected(const QString&);
-
     private: /* Methods: */
 
         void retranslateUi();
@@ -62,9 +60,9 @@ class BtFontSettingsPage: public BtConfigDialog::Page {
         QLabel *m_languageLabel;
         QComboBox *m_languageComboBox;
         QCheckBox *m_languageCheckBox;
-        BtFontChooserWidget* m_fontChooser;
+        QFontDialog * m_fontChooser;
 
-        FontMap m_fontMap;
+        std::vector<WorkSetting> m_workSettings;
 
 };
 
