@@ -47,8 +47,13 @@ CAcceleratorSettingsPage::CAcceleratorSettingsPage(CConfigurationDialog *parent)
     m_typeChooser = new QComboBox(this);
     layoutForWindowTypeChooser->addWidget(m_typeChooser);
 
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
     BT_CONNECT(m_typeChooser, SIGNAL(activated(QString const &)),
-               SLOT(slotKeyChooserTypeChanged(QString const &)) );
+        SLOT(slotKeyChooserTypeChanged(QString const&)) );
+#else
+    BT_CONNECT(m_typeChooser, SIGNAL(textActivated(QString const &)),
+        SLOT(slotKeyChooserTypeChanged(QString const&)));
+#endif
 
     // m_*.title strings are empty here, they are filled and added to the stacked widget in the retranslateUi() function
     m_keyChooserStack = new QStackedWidget(this);
