@@ -1,28 +1,31 @@
 /*********
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
+*
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
-#include "frontend/settingsdialogs/cconfigurationdialog.h"
+#include "cconfigurationdialog.h"
 
 #include <QAbstractButton>
 #include <QDialogButtonBox>
 #include <QLayout>
 #include <QPushButton>
 #include <QWidget>
-#include "backend/config/btconfig.h"
-#include "frontend/settingsdialogs/cacceleratorsettings.h"
-#include "frontend/settingsdialogs/cdisplaysettings.h"
-#include "frontend/settingsdialogs/btfontsettings.h"
-#include "frontend/settingsdialogs/cswordsettings.h"
-#include "frontend/messagedialog.h"
-#include "util/btconnect.h"
-#include "util/cresmgr.h"
-#include "util/directory.h"
+#include "../../backend/config/btconfig.h"
+#include "../../util/btconnect.h"
+#include "../../util/cresmgr.h"
+#include "../../util/directory.h"
+#include "../messagedialog.h"
+#include "btfontsettings.h"
+#include "cacceleratorsettings.h"
+#include "cdisplaysettings.h"
+#include "cswordsettings.h"
 
 
 namespace {
