@@ -2,10 +2,11 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
@@ -21,7 +22,6 @@ class CConfigurationDialog;
 class QCheckBox;
 class QComboBox;
 class QLabel;
-class BtWebEngineView;
 
 class CDisplaySettingsPage: public BtConfigDialog::Page {
 
@@ -47,6 +47,7 @@ class CDisplaySettingsPage: public BtConfigDialog::Page {
 
         static QVector<QString> bookNameAbbreviationsTryVector();
         void initSwordLocaleCombo();
+        void updateColors(const QString& style = QString());
 
     private: /* Fields: */
 
@@ -57,7 +58,7 @@ class CDisplaySettingsPage: public BtConfigDialog::Page {
         QLabel *m_transifexLabel;
         QComboBox* m_styleChooserCombo;
         QLabel *m_availableLabel;
-        BtWebEngineView* m_stylePreviewViewer;
+        QLabel* m_stylePreviewViewer;
         QLabel *m_previewLabel;
 
 };
