@@ -1,25 +1,27 @@
 /*********
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* Copyright 1999-2014 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
+*
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
-#include "frontend/settingsdialogs/cswordsettings.h"
+#include "cswordsettings.h"
 
 #include <QVBoxLayout>
-#include "bibletimeapp.h"
-#include "frontend/settingsdialogs/btstandardworkstab.h"
-#include "frontend/settingsdialogs/bttextfilterstab.h"
-#include "frontend/settingsdialogs/cconfigurationdialog.h"
-#include "util/cresmgr.h"
-#include "util/geticon.h"
+#include "../../util/cresmgr.h"
+#include "../bibletimeapp.h"
+#include "btstandardworkstab.h"
+#include "bttextfilterstab.h"
+#include "cconfigurationdialog.h"
 
 
 CSwordSettingsPage::CSwordSettingsPage(CConfigurationDialog * parent)
-        : BtConfigDialog::Page(util::getIcon(CResMgr::settings::sword::icon), parent)
+        : BtConfigDialog::Page(CResMgr::settings::sword::icon(), parent)
 {
     static const QString nullString;
 
