@@ -2,10 +2,11 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
 *
-* Copyright 1999-2014 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
@@ -21,8 +22,7 @@ class QCheckBox;
 class QDialogButtonBox;
 class QPushButton;
 class QUrl;
-class QWebView;
-
+class QTextBrowser;
 /**
   The Tip Of The Day dialog.
 */
@@ -31,7 +31,7 @@ class BtTipDialog: public QDialog {
 
     public: /* Methods: */
 
-        BtTipDialog(QWidget *parent = 0, Qt::WindowFlags wflags = Qt::Dialog);
+        BtTipDialog(QWidget *parent = nullptr, Qt::WindowFlags wflags = Qt::Dialog);
 
     private: /* Methods: */
 
@@ -55,7 +55,7 @@ class BtTipDialog: public QDialog {
     private: /* Fields: */
 
         QDialogButtonBox* m_buttonBox;
-        QWebView* m_tipView;
+        QTextBrowser* m_tipView;
         QCheckBox* m_showTipsCheckBox;
         int m_tipNumber;
         QStringList m_tips;
