@@ -1,9 +1,12 @@
 /*********
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
+*
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
@@ -17,6 +20,8 @@
 #include <QFileInfo>
 #include <QFileInfoList>
 #include <QLocale>
+#include <QStandardPaths>
+#include <QStringList>
 #include "btassert.h"
 #ifdef Q_OS_WIN32
 #include <windows.h>
@@ -29,14 +34,11 @@ namespace directory {
 namespace {
 
 std::unique_ptr<QDir> cachedIconDir;
-std::unique_ptr<QDir> cachedJavascriptDir;
 std::unique_ptr<QDir> cachedLicenseDir;
 std::unique_ptr<QDir> cachedPicsDir;
 std::unique_ptr<QDir> cachedLocaleDir;
-std::unique_ptr<QDir> cachedHandbookDir;
-std::unique_ptr<QDir> cachedHowtoDir;
+std::unique_ptr<QDir> cachedDocDir;
 std::unique_ptr<QDir> cachedDisplayTemplatesDir;
-std::unique_ptr<QDir> cachedQmlDir;
 std::unique_ptr<QDir> cachedUserDisplayTemplatesDir;
 std::unique_ptr<QDir> cachedUserBaseDir;
 std::unique_ptr<QDir> cachedUserHomeDir;
@@ -51,7 +53,7 @@ std::unique_ptr<QDir> cachedApplicationSwordDir; // Only Windows installs the sw
 std::unique_ptr<QDir> cachedSharedSwordDir;
 #endif
 
-#ifdef Q_OS_MAC
+#ifdef Q_OS_MACOS
 std::unique_ptr<QDir> cachedSwordLocalesDir;
 #endif
 
@@ -78,9 +80,9 @@ static const char SWORD_PATH[] = "SWORD_PATH";
 bool initDirectoryCache() {
     QDir wDir(":/share/bibletime"); // check if resources would be read from qrc
     if(wDir.exists())
-        wDir = ":/";
+        wDir.setPath(":/");
     else {
-        wDir = QCoreApplication::applicationDirPath();
+        wDir.setPath(QCoreApplication::applicationDirPath());
         wDir.makeAbsolute();
         if (!wDir.cdUp()) { // Installation prefix
             qWarning() << "Cannot cd up from directory " << QCoreApplication::applicationDirPath();
@@ -99,29 +101,21 @@ bool initDirectoryCache() {
 
 #ifdef Q_OS_WIN
     cachedApplicationSwordDir.reset(new QDir(wDir)); // application sword dir for Windows only
-#if !defined BT_MINI && !defined BT_MOBILE
     if (!cachedApplicationSwordDir->cd("share/sword") || !cachedApplicationSwordDir->isReadable()) {
         qWarning() << "Cannot find sword directory relative to" << QCoreApplication::applicationDirPath();
         return false;
     }
-#endif
-
-#if !defined Q_OS_WINCE && !defined BT_MOBILE && !defined Q_OS_WINRT
-    cachedSharedSwordDir.reset(new QDir(qgetenv("ProgramData"))); // sword dir for Windows only
-    if (!cachedSharedSwordDir->cd("Application Data")) {
-        qWarning() << "Cannot find %ProgramData%";
-        return false;
-    }
+    QByteArray programDataDir = qgetenv("ProgramData");
+    cachedSharedSwordDir.reset(new QDir(programDataDir)); // sword dir for Windows only
     if (!cachedSharedSwordDir->cd(SWORD_DIR)) {
         if (!cachedSharedSwordDir->mkdir(SWORD_DIR) || !cachedSharedSwordDir->cd(SWORD_DIR)) {
-            qWarning() << "Cannot find %ProgramData%\\Sword";
+            qWarning() << "Cannot find " << programDataDir << " \\Sword";
             return false;
         }
     }
 #endif
-#endif
 
-#ifdef Q_OS_MAC
+#ifdef Q_OS_MACOS
     cachedSwordLocalesDir.reset(new QDir(wDir)); // application sword dir for Windows only
     if (!cachedSwordLocalesDir->cd("share/sword/locales.d") || !cachedSwordLocalesDir->isReadable()) {
         qWarning() << "Cannot find sword locales directory relative to" << QCoreApplication::applicationDirPath();
@@ -148,13 +142,6 @@ bool initDirectoryCache() {
         return false;
     }
 
-#ifndef BT_MINI
-    cachedJavascriptDir.reset(new QDir(wDir));
-    if (!cachedJavascriptDir->cd("share/bibletime/javascript") || !cachedJavascriptDir->isReadable()) {
-        qWarning() << "Cannot find javascript directory relative to" << wDir.absolutePath();
-        return false;
-    }
-
     cachedLicenseDir.reset(new QDir(wDir));
     if (!cachedLicenseDir->cd("share/bibletime/license") || !cachedLicenseDir->isReadable()) {
         qWarning() << "Cannot find license directory relative to" << wDir.absolutePath();
@@ -166,7 +153,6 @@ bool initDirectoryCache() {
         qWarning() << "Cannot find pics directory relative to" << wDir.absolutePath();
         return false;
     }
-#endif
 
     cachedLocaleDir.reset(new QDir(wDir));
     if (!cachedLocaleDir->cd("share/bibletime/locale")) {
@@ -174,30 +160,16 @@ bool initDirectoryCache() {
         return false;
     }
 
-    QString localeName(QLocale::system().name());
+    QString localeName(QLocale().name());
     QString langCode(localeName.section('_', 0, 0));
 
-#ifndef BT_MINI
-    cachedHandbookDir.reset(new QDir(wDir));
-    if (!cachedHandbookDir->cd("share/bibletime/docs/handbook/" + localeName)) {
-        if (!cachedHandbookDir->cd("share/bibletime/docs/handbook/" + langCode)) {
-            if (!cachedHandbookDir->cd("share/bibletime/docs/handbook/en/")) {
-                qWarning() << "Cannot find handbook directory relative to" << wDir.absolutePath();
-                return false;
-            }
-        }
-    }
 
-    cachedHowtoDir.reset(new QDir(wDir));
-    if (!cachedHowtoDir->cd("share/bibletime/docs/howto/" + localeName)) {
-        if (!cachedHowtoDir->cd("share/bibletime/docs/howto/" + langCode)) {
-            if (!cachedHowtoDir->cd("share/bibletime/docs/howto/en/")) {
-                qWarning() << "Cannot find handbook directory relative to" << wDir.absolutePath();
-                return false;
-            }
-        }
+    cachedDocDir.reset(new QDir(wDir));
+    if (!cachedDocDir->cd(BT_RUNTIME_DOCDIR)) {
+        qWarning() << "Cannot find documentation directory relative to"
+                   << wDir.absolutePath();
+        return false;
     }
-#endif
 
     cachedDisplayTemplatesDir.reset(new QDir(wDir)); //display templates dir
     if (!cachedDisplayTemplatesDir->cd("share/bibletime/display-templates/")) {
@@ -205,14 +177,6 @@ bool initDirectoryCache() {
         return false;
     }
 
-#ifdef BT_MOBILE
-    cachedQmlDir.reset(new QDir(wDir)); //qml files dir
-    if (!cachedQmlDir->cd("share/bibletime/qml/")) {
-        qWarning() << "Cannot find qml relative to" << wDir.absolutePath();
-        return false;
-    }
-#endif
-
 #ifdef Q_OS_WINRT
     cachedUserHomeDir.reset(new QDir(""));
 #elif defined (Q_OS_WIN) && !defined(Q_OS_WIN32)
@@ -387,7 +351,7 @@ const QDir &getSharedSwordDir() {
 
 #endif
 
-#ifdef Q_OS_MAC
+#ifdef Q_OS_MACOS
 const QDir &getSwordLocalesDir() {
     return *cachedSwordLocalesDir;
 }
@@ -401,10 +365,6 @@ const QDir &getIconDir() {
     return *cachedIconDir;
 }
 
-const QDir &getJavascriptDir() {
-    return *cachedJavascriptDir;
-}
-
 const QDir &getLicenseDir() {
     return *cachedLicenseDir;
 }
@@ -417,25 +377,53 @@ const QDir &getLocaleDir() {
     return *cachedLocaleDir;
 }
 
-const QDir &getHandbookDir() {
-    return *cachedHandbookDir;
+namespace {
+
+QString getDocFile(QString docName) {
+    auto dir(*cachedDocDir);
+    QString r;
+    if (dir.cd(docName)) {
+        QStringList tryLanguages;
+        tryLanguages.append(QLocale().name());
+        {
+            auto const & localeName = tryLanguages.back();
+            if (localeName.contains('_'))
+                tryLanguages.append(localeName.section('_', 0, 0));
+        }
+        tryLanguages.append("en");
+        auto const tryDoc =
+                [&dir,&tryLanguages](QString const & type,
+                                     QString const & filename) -> QString
+                {
+                    if (dir.cd(type)) {
+                        for (auto const & tryLanguage : tryLanguages) {
+                            if (dir.cd(tryLanguage)) {
+                                if (dir.exists(filename))
+                                    return dir.absoluteFilePath(filename);
+                                dir.cdUp();
+                            }
+                        }
+                        dir.cdUp();
+                    }
+                    return {};
+                };
+        r = tryDoc("html", "index.html");
+        if (r.isEmpty())
+            r = tryDoc("pdf", docName + ".pdf");
+    }
+    return r;
 }
 
-const QDir &getHowtoDir() {
-    return *cachedHowtoDir;
-}
+} // anonymous namespace
+
+QString getHandbook() { return getDocFile("handbook"); }
+
+QString getHowto() { return getDocFile("howto"); }
 
 const QDir &getDisplayTemplatesDir() {
     return *cachedDisplayTemplatesDir;
 }
 
-const QDir &getQmlDir() {
-#ifndef BT_MOBILE
-    BT_ASSERT(false && "Qml files currently required for BibleTime Mobile frontend only.");
-#endif
-    return *cachedQmlDir;
-}
-
 const QDir &getUserBaseDir() {
     return *cachedUserBaseDir;
 }
