@@ -2,10 +2,11 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/.
+* This file is part of BibleTime's source code, http://www.bibletime.info/
 *
-* Copyright 1999-2016 by the BibleTime developers.
-* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+* Copyright 1999-2020 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License
+* version 2.0.
 *
 **********/
 
@@ -19,20 +20,6 @@
 */
 
 
-/**
-  \def DEPRECATED(func)
-  \brief Macro for declaring functions and methods as deprecated.
-*/
-
-#ifdef __GNUC__
-    #define DEPRECATED(func) func __attribute__ ((deprecated))
-#elif defined(_MSC_VER)
-    #define DEPRECATED(func) __declspec(deprecated) func
-#else
-    #define DEPRECATED(func) func
-#endif
-
-
 /**
   \def LIKELY(c)
   \brief Gives the compiler a hint that the given conditional is likely to
